@@ -10,7 +10,7 @@ use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION $USE_REGISTRAR_SERVERS);
 @ISA = qw(Exporter);
 @EXPORT = qw( expire_date expdate_fmt expdate_int );
 @EXPORT_OK = qw( decode_date );
-$VERSION = '0.23';
+$VERSION = '0.24';
 
 $USE_REGISTRAR_SERVERS = 0; # Don't make direct queries to registrar server
 
@@ -55,7 +55,7 @@ sub expdate_int {
 
     if ($tld eq 'ru' || $tld eq 'su') {
 	return expdate_int_ru( $whois );
-    } elsif (isin($tld, ['com', 'net', 'org', 'biz', 'info', 'us'])) {
+    } elsif (isin($tld, ['com', 'net', 'org', 'biz', 'info', 'us', 'uk'])) {
 	return expdate_int_cno( $whois );
     } else {
 	return undef;
@@ -104,7 +104,8 @@ sub expdate_int_cno {
     # [whois.discount-domain.com]	Expiration Date: 02-Aug-2003 22:07:21
     # [whois.publicinterestregistry.net] Expiration Date:03-Mar-2004 05:00:00 UTC
     # [whois.crsnic.net]		Expiration Date: 21-sep-2004
-    } elsif ($whois =~ m/Expiration Date:\s*(\d{2})-(\w{3})-(\d{4})/s) {
+    # [whois.nic.uk]			Renewal Date:   23-Jan-2006
+    } elsif ($whois =~ m/(?:Expiration|Renewal) Date:\s*(\d{2})-(\w{3})-(\d{4})/s) {
 	$rulenum = 1.2;	$d = $1; $b = $2; $Y = $3;
     # [whois.bulkregister.com]		Record expires on 2003-04-25
     # [whois.bulkregister.com]		Record will be expiring on date: 2003-04-25
